@@ -7,12 +7,11 @@ SCRIPT_HOME="$(cd "$(dirname "$0")" && pwd)"
 BIFROST_HOME=$SCRIPT_HOME/..
 ANSIBLE_INSTALL_ROOT=${ANSIBLE_INSTALL_ROOT:-/opt/stack}
 USE_DHCP="${USE_DHCP:-false}"
-USE_VENV="${USE_VENV:-true}"
 BUILD_IMAGE="${BUILD_IMAGE:-false}"
 BAREMETAL_DATA_FILE=${BAREMETAL_DATA_FILE:-'/tmp/baremetal.json'}
 ENABLE_KEYSTONE="${ENABLE_KEYSTONE:-false}"
 ZUUL_BRANCH=${ZUUL_BRANCH:-}
-ZUUL_REF=${ZUUL_REF:-}
+ENABLE_VENV=${ENABLE_VENV:-true}
 
 # Set defaults for ansible command-line options to drive the different
 # tests.
@@ -25,7 +24,6 @@ ZUUL_REF=${ZUUL_REF:-}
 # placed in the configuration drive. The "build image" test does not
 # use cirros.
 
-VM_MEMORY_SIZE="3072"
 # NOTE(rpittau) we can't use kvm in CI
 VM_DOMAIN_TYPE=qemu
 export VM_DISK_CACHE="unsafe"
@@ -44,73 +42,39 @@ PROVISION_WAIT_TIMEOUT=${PROVISION_WAIT_TIMEOUT:-900}
 NOAUTH_MODE=true
 CLOUD_CONFIG=""
 WAIT_FOR_DEPLOY=true
-ENABLE_VENV=true
 
-# This sets up the MySQL database like it's done for all OpenStack
-# projects for CI testing.
-mysql_setup() {
-    # The root password for the MySQL database; pass it in via
-    # MYSQL_ROOT_PW.
-    local DB_ROOT_PW=${MYSQL_ROOT_PW:-insecure_slave}
-
-    # This user and its password are used by the tests, if you change it,
-    # your tests might fail.
-    local DB_USER=openstack_citest
-    local DB_PW=openstack_citest
-
-    # Make sure MySQL is running
-    sudo service mysql start || sudo service mysqld start || sudo service mariadb start
-
-    sudo -H mysqladmin -u root password $DB_ROOT_PW
-
-    # It's best practice to remove anonymous users from the database.  If
-    # an anonymous user exists, then it matches first for connections and
-    # other connections from that host will not work.
-    sudo -H mysql -u root -p$DB_ROOT_PW -h localhost -e "
-        DELETE FROM mysql.user WHERE User='';
-        FLUSH PRIVILEGES;
-        GRANT ALL PRIVILEGES ON *.*
-            TO '$DB_USER'@'%' identified by '$DB_PW' WITH GRANT OPTION;"
-
-    # Now create our database.
-    mysql -u $DB_USER -p$DB_PW -h 127.0.0.1 -e "
-        SET default_storage_engine=MYISAM;
-        DROP DATABASE IF EXISTS openstack_citest;
-        CREATE DATABASE openstack_citest CHARACTER SET utf8;"
-}
+# Get OS information
+source /etc/os-release || source /usr/lib/os-release
+OS_DISTRO="$ID"
 
 # Setup openstack_ci test database if run in OpenStack CI.
-if [ "$ZUUL_BRANCH" != "" -a "$ZUUL_REF" ]; then
-    mysql_setup
+if [ "$ZUUL_BRANCH" != "" ]; then
+    sudo mkdir -p /opt/libvirt/images
+    VM_SETUP_EXTRA="-e test_vm_storage_pool_path=/opt/libvirt/images"
 fi
 
-if [ ${USE_VENV} = "true" ]; then
-    export VENV=/opt/stack/bifrost
-    $SCRIPT_HOME/env-setup.sh
+source $SCRIPT_HOME/env-setup.sh
+if [ ${ENABLE_VENV} = "true" ]; then
     # Note(cinerama): activate is not compatible with "set -u";
     # disable it just for this line.
     set +u
     source ${VENV}/bin/activate
     set -u
     ANSIBLE=${VENV}/bin/ansible-playbook
-    ENABLE_VENV="true"
     ANSIBLE_PYTHON_INTERP=${VENV}/bin/python3
 else
-    $SCRIPT_HOME/env-setup.sh
     ANSIBLE=${HOME}/.local/bin/ansible-playbook
     ANSIBLE_PYTHON_INTERP=$(which python3)
 fi
 
 # Adjust options for DHCP, VM, or Keystone tests
 if [ ${USE_DHCP} = "true" ]; then
-    VM_MEMORY_SIZE="1024"
     ENABLE_INSPECTOR=false
     INSPECT_NODES=false
     TEST_VM_NUM_NODES=3
     INVENTORY_DHCP=true
     INVENTORY_DHCP_STATIC_IP=true
     WRITE_INTERFACES_FILE=false
-    VM_DISK=12
 elif [ ${BUILD_IMAGE} = "true" ]; then
     USE_CIRROS=false
     TESTING_USER=root
@@ -119,6 +83,17 @@ elif [ ${BUILD_IMAGE} = "true" ]; then
     INSPECT_NODES=false
     DOWNLOAD_IPA=false
     CREATE_IPA_IMAGE=true
+
+    # if running in OpenStack CI, then make sure epel is enabled
+    # since it may already be present (but disabled) on the host
+    # we need epel for debootstrap
+    if env | grep -q ^ZUUL; then
+        if [[ "$OS_DISTRO" == "rhel" ]] || [[ "$OS_DISTRO" == "centos" ]]; then
+            sudo dnf install -y dnf-utils
+            sudo dnf install -y epel-release || true
+            sudo dnf config-manager --set-enabled epel || true
+        fi
+    fi
 elif [ ${ENABLE_KEYSTONE} = "true" ]; then
     NOAUTH_MODE=false
     CLOUD_CONFIG="-e cloud_name=bifrost"
@@ -151,12 +126,13 @@ ${ANSIBLE} -vvvv \
        test-bifrost-create-vm.yaml \
        -e ansible_python_interpreter="${ANSIBLE_PYTHON_INTERP}" \
        -e test_vm_num_nodes=${TEST_VM_NUM_NODES} \
-       -e test_vm_memory_size=${VM_MEMORY_SIZE} \
+       -e test_vm_memory_size=${VM_MEMORY_SIZE:-512} \
        -e test_vm_domain_type=${VM_DOMAIN_TYPE} \
-       -e test_vm_disk_gib=${VM_DISK:-10} \
+       -e test_vm_disk_gib=${VM_DISK:-5} \
        -e baremetal_json_file=${BAREMETAL_DATA_FILE} \
        -e enable_venv=${ENABLE_VENV} \
-       -e bifrost_venv_dir=${VENV}
+       -e bifrost_venv_dir=${VENV} \
+       ${VM_SETUP_EXTRA:-}
 
 if [ ${USE_DHCP} = "true" ]; then
     # reduce the number of nodes in JSON file
